@@ -18,11 +18,11 @@ def params_check(fn=None, *, required: list = None, optional: list = None, debug
 
     def inner(f):
         @functools.wraps(f)
-        def _inner(**kwargs):
+        def _inner(*args, **kwargs):
             _check_required(f.__name__, **kwargs)
             _check_optional(f.__name__, **kwargs)
 
-            return f(**kwargs)
+            return f(*args, **kwargs)
 
         return _inner
 
